@@ -934,12 +934,12 @@ class Askdata(SignUp):
                 }
 
                 headers = {
-                    "Authorization": "Basic YXNrZGF0YS1zZGs6YXNrZGF0YS1zZGs=",
+                    "Authorization": "Basic c21hcnRhZ2VudDpzbWFydGFnZW50",
                     "Content-Type": "application/x-www-form-urlencoded",
                     "cache-control": "no-cache,no-cache"
                 }
 
-                authentication_url = self.base_url_security + '/domain/' + self._domainlogin.lower() + '/oauth/token'
+                authentication_url = self.base_url + '/security/domain/' + self._domainlogin.lower() + '/oauth/token'
 
                 # request token for the user
                 r1 = s.post(url=authentication_url, data=data, headers=headers)
@@ -947,8 +947,8 @@ class Askdata(SignUp):
                 self._token = r1.json()['access_token']
                 self.r1 = r1
 
-            print(self._token)
-            authentication_url_userid = self.base_url + '/me'
+
+            authentication_url_userid = self.base_url+ '/security/me'
             self._headers = {
                 "Content-Type": "application/json",
                 "Authorization": "Bearer" + " " + self._token
